@@ -31,82 +31,63 @@ class CoroutineClass(ABC):
 
             .. code-block:: python
 
-                from toolbox.asyncio.pattern import CoroutineClass
+                from toolbox import CoroutineClass
                 import asyncio
 
-                class AsyncClass(CoroutineClass):
+                class Coroutine(CoroutineClass):
                     def __init__(self, run: bool = False):
-                        super().__init__(
-                            self.entry,
-                            start_callback=lambda: print("Starting!"),
-                            end_callback=lambda: print("Stopping!"),
-                            run=True,
-                        )
+                        super().__init__(run=run)
 
+                    # Default entry function.
                     async def entry(self):
-                        print("Running the CoroutineClass.")
-                        await asyncio.sleep(5)
-                        print("Finished running the CoroutineClass.")
-                        return "Returning from the CoroutineClass."
+                        await asyncio.sleep(1)
+                        return "Hello world"
 
-                async def test_async():
-                    # Using CoroutineClass inside an async function does not block the main thread.
-                    # The only way to force the main thread to wait is to await the CoroutineClass.
-                    print("--- async ---\n")
+                # Start coroutine outside Python async context.
+                def iomain():
 
-                    # Use with __init__.
-                    print("Running: __init__")
-                    process = AsyncClass(run=True)
-                    await asyncio.sleep(1)  # We do not 'await process'.
-                    process.stop()
-                    print("\n")
+                    # via __init__
+                    coro = Coroutine(run=True)
+                    print(coro.result)  # Hello world
 
-                    # Use with functions to start/stop.
-                    print("Running: .run() & .stop()")
-                    process = AsyncClass()
-                    process.run()
-                    await asyncio.sleep(1)  # We do not 'await process'.
-                    process.stop()
-                    print("\n")
+                    # via .run()
+                    coro = Coroutine()
+                    result = coro.run()
+                    print(result)  # Hello world
 
-                    # Use with context manager to start/stop. Notice this will block.
-                    print("Running: async with")
-                    async with AsyncClass() as process:
-                        result = await process  # We do wait for process.
-                    print(f"Returned: {result}\n")
+                # Start coroutine inside Python async context.
+                async def aiomain():
 
-                    # Awaits for the process to finish. Notice this will block.
-                    print("await process")
-                    process = AsyncClass()
-                    result = await process  # We do wait for process.
-                    print(f"Returned: {result}\n")
+                    # via __init__
+                    coro = Coroutine(run=True)
+                    await asyncio.sleep(1)
+                    coro.stop()
+                    print(coro.result)  # None - because process was stopped before completion.
 
-                def test_sync():
-                    # Using CoroutineClass inside a sync function blocks the main thread.
-                    # No need to wait for the CoroutineClass.
-                    print("--- sync ---\n")
+                    # via .run()
+                    coro = Coroutine()
+                    coro.run()
+                    await asyncio.sleep(1)
+                    result = coro.stop()  # None - because coroutine was stopped before completion.
+                    print(result)  # Hello world
 
-                    # Notice that this will block.
-                    print("Running: __init__")
-                    process = AsyncClass(run=True)
-                    result = process.result
-                    print(f"Returned: {result}\n")
+                    # via await
+                    coro = Coroutine()
+                    result = await coro  # You can also start, and await later.
+                    print(result)  # Hello World
 
-                    # Notice that this will also block.
-                    print("Running: .run()")
-                    process = AsyncClass()
-                    process.run()
-                    result = process.result
-                    print(f"Returned: {result}\n")
-
-                asyncio.run(test_async())
-                test_sync()
+                    # via context manager
+                    async with Coroutine() as coro:
+                        result = await coro
+                    print(result)  # Hello World
 
         """
         self._func = func if func else self.entry
         self._start_callback = start_callback
         self._end_callback = end_callback
         self._task = None
+
+        # Setup the asyncio loop.
         try:
             loop = asyncio.get_event_loop()
         except RuntimeError:  # pragma: no cover
@@ -115,6 +96,8 @@ class CoroutineClass(ABC):
         finally:
             self._loop = loop
 
+        self.result = None
+
         if run:
             self.run()
 
@@ -131,31 +114,56 @@ class CoroutineClass(ABC):
         Note:
             The task will block if we call this method outside an async context.
         """
+
+        # If task is not running or has been cancelled, start it.
         if not self._task or self._task.cancelled():
+
+            # Call the start callback.
             if self._start_callback:
                 self._start_callback()
+
+            # Creates the task inside the loop.
             self._task = self._loop.create_task(self._func())
+
+            # Add self.stop as callback for when the task is done.
             self._task.add_done_callback(self.stop)
+
+            # Runs the loop if we are not in an async context.
             if not self._loop.is_running():
+                # Runs task until completion. Calls self.stop.
                 self._loop.run_until_complete(self._task)
                 return self.result
 
     def stop(self, result: Optional[Any] = None) -> Any:
         """
         Stops the task without blocking.
+
+        Args:
+            result: The result to return when the task is stopped.
+
+        Notes:
+            This function is attached as a callback to the task.
         """
+
+        # If task is running and hasn't been cancelled, cancel it.
         if self._task and not self._task.cancelled():
-            if self._end_callback:
-                self._end_callback()
+
+            # Cancel task.
             self._task.cancel()
 
-        self.result = None
+            # Call the end callback.
+            if self._end_callback:
+                self._end_callback()
+
+        # Tries the get the result of the task.
         if self._task.done():
             try:
                 self.result = self._task.result()
             except asyncio.CancelledError:  # pragma: no cover
                 pass
-        return self.result
+
+            # Return the result.
+            return self.result
 
     async def __aenter__(self) -> type:
         """
@@ -168,8 +176,8 @@ class CoroutineClass(ABC):
         """
         Exit the async context manager.
         """
-        if self._task:
-            return self._task.cancelled()
+        self.stop()
+        return self._task.cancelled()
 
     def __await__(self):
         """
