@@ -8,14 +8,15 @@ class Item:
     __slots__ = ["_item", "_type"]
 
     def __init__(self, item: ItemType):
-        """An interface for type-agnostic operations between ``bytes``, ``str``, ``int``, ``bool``,
-        and ``None``.
+        """
+        An interface for type-agnostic operations between ``bytes``, ``str``, ``int``,
+         ``bool``, and ``None``.
+
+        Internally, the passed ``item`` object is stored as its ``bytes``
+        representation. Any operation or modification to the new ``Item`` instance is
+        done to the internal ``bytes`` object. The true usefulness of this container is
+        for type-agnostic operations such as equality checks.
 
-        Internally, the passed ``item`` object is stored as its ``bytes`` representation. Any
-        operation or modification to the new ``Item`` instance is done to the internal ``bytes``
-        object. The true usefulness of this container is for type-agnostic operations such as
-        equality checks.
-        
         Args:
             item: Input to be stored.
 
@@ -40,19 +41,25 @@ class Item:
 
     @property
     def raw(self) -> bytes:
-        """Bytes representation of the passed item."""
+        """
+        Bytes representation of the passed item.
+        """
         return self._item
 
     @property
     def string(self) -> str:
-        """String representation of the passed item."""
+        """
+        String representation of the passed item.
+        """
         return self._item.decode(ENCODE)
 
     @property
     def integer(self) -> Union[int, None]:
-        """Integer representation of the passed item.
+        """
+        Integer representation of the passed item.
 
-        If passed item is not a sub class of type int or str.isdigit() this property returns None.
+        If passed item is not a sub class of type int or str.isdigit() this property
+        returns None.
         """
         if issubclass(self._type, int) or self.string.isdigit():
             return int(self._item)
@@ -61,7 +68,9 @@ class Item:
 
     @property
     def boolean(self) -> bool:
-        """Boolean representation of the passed item."""
+        """
+        Boolean representation of the passed item.
+        """
         if issubclass(self._type, int):
             return bool(int(self._item))
         else:
@@ -69,7 +78,9 @@ class Item:
 
     @property
     def original(self) -> ItemType:
-        """Original representation of the passed item."""
+        """
+        Original representation of the passed item.
+        """
         if self._type is str and isinstance(self._item, bytes):
             return self._item.decode(ENCODE)
         elif self._type is type(None):
@@ -78,7 +89,8 @@ class Item:
         return self._type(self._item)
 
     def replace(self, old: ItemType, new: ItemType, count: int = -1) -> bytes:
-        """``bytes.replace()`` functionality on item.
+        """
+        ``bytes.replace()`` functionality on item.
 
         See Python `docs <https://docs.python.org/3/library/stdtypes.html?highlight=replace#bytes.replace>`_ for more info.
         """
@@ -87,7 +99,8 @@ class Item:
         return self.raw.replace(old, new, count)
 
     def __pos__(self):
-        """Returns the string representation of the object.
+        """
+        Returns the string representation of the object.
 
         Example:
 
@@ -101,7 +114,8 @@ class Item:
         return self.string
 
     def __neg__(self):
-        """Returns the integer representation of the object.
+        """
+        Returns the integer representation of the object.
 
         Example:
 
@@ -164,7 +178,8 @@ class Item:
 
     @staticmethod
     def byte_item(item: ItemType) -> "Item":
-        """Converts passed item into its bytes representation, and returns an Item instance.
+        """
+        Converts passed item into its bytes representation, and returns an Item instance.
 
         Args:
             item: Item of str, bytes, int, bool, None, or Item to convert to an Item.
